function n=concentrations()
% Let's try to estimate absolute concentration of lead atoms in diffusion flame atomizer!
% For evaluation, use the averaged value of central part of flame on pictures 1-40 in file "citlivost1.SPE".


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% How to find these values?

M = []; % mean fluorescence signal in the central part of the flame
E_L = []; % mean energy of laser pulses 
tau = []; % lifetime of the excited state


% You can assume:
	wvl_laser = 283.30534e-9; 
	wvl_fluor = 405.78067e-9;
	A32 = 9.0e7;
	A31 = 4.9e7;
	B13 = AtoB(A31, wvl_laser);
	c = 299792458;
	kappa = 2e-11; % spectral overlap of laser and absorption line
	C = camera_sensitivity_interp(wvl_fluor);
	T = 0.42; % transmissivity of the filter for fluorescence
	beta_E = 1e5; 
	satur = (1 + beta_E * E_L); % correction factor for the saturation effects
	M_c = 1e5; % mean calibration signal FROM ONE PIXEL (and the same measurement conditions as in fluorescence measurement)
	M_ctheor = 2e12; % theoretical calibration signal (including camera sensitivity, laser energy, ... everything is in SI units)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Now it is your way to calculate the Pb concentration:
n = [];



end










%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function b=AtoB(a, wvl)
h = 6.626e-34;
c = 299792458;
f = c/wvl;
F = 2 * h * f^3 / c^3;
b = a / F;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function C = camera_sensitivity_interp(vln)
tab = load('pimax_1024.dat');  % the table is in nanometers
x = tab(:,1);
y = tab(:,2);
C = interp1(x, y, vln*1e9);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%