function [M,S]=rozdel_energie(EL,n,acc,mocnina,tv)
%[M,S]=rozdel_energie(EL,n,acc,mocnina,tv)
%Rozdeluje soubor s energiemi laseru (EL) do casti odpovidajicich jednotlivym obrazkum kamery 
% a v techto castech pocita prumernou energii laserovych pulzu. 
%"n" je pocet snimku merenych kamerou, 
%"acc" je pocet laserovych pulzu jdoucich behem mereni kazdeho snimku (tj. pocet akumulaci kamery). 
%Vystupni vektor "M" obsahuje prumerne hodnoty energie laseru pro jednotlive snimky. 
%Vystupni vektor "S" obsahuje standardni odchylky energii laseru umocnenych na cislo "mocnina" pro kazdy snimek 
% (na rozdil od prumernych energii se standardni odchylky neprepocitavaji zpet na prvni mocninu). 
%
%Je-li zadan parametr "mocnina", tak se energie laseru pred prumerovanim umocni na tuto mocninu 
% a po zprumerovani odmocni zpet, aby vysledek opet odpovidal energii.
%"tv" je doba vycitani kamery mezi jednotlivymi snimky. 
%Parametry "mocnina" a "tv" nemuseji byt zadane, lze tedy volat napr. jen 
% M=rozdel_energie(EL,n,acc);, 
% pak se automaticky pocita s prvni mocninou a doba vycitani se odhaduje pro cely cip. 
%
%Je-li merenych pulzu dostatek, pak funkce vynechava pulzy, o kterych si mysli, za sly behem vycitani kamery. 
%Je-li orez=1, pak se funkce pokousi vypustit laserove pulzy jdouci pred spustenim kamery (po dobu tp)
% a pulzy jdouci po skonceni mereni (proto se snazi odhadnout dobu vycitani kazdeho snimku). 
%Je-li orez=0, pak veliciny "tp", "tv" nemaji na vysledek vliv. 

orez=1; 
tp=0.1; %Odhad zpozdeni mezi spustenim mereni energii a spustenim mereni kamerou
f=30; %Frekvence laserovych pulzu
switch nargin
 case 3
  mocnina=1;
  tv=0.269536;
 case 4
  tv=0.269536;
end

%Oriznuti pravdepodobne prebytecnych hodnot: 
m=length(EL);
por=round(n*acc + (n-1)*f*tv + f*tp);
if m>por & orez==1 %Kdyz experimentator zapomnel stopnout mereni energii a soubor je moc dlouhy,
 EL=EL(round(f*tp)+1:por); % tak se mereni orizne podle jeho ocekavane delky. 
 m=length(EL); 
end
r=n*acc;
if m<((n-1)*acc+1)
 disp('Mereni energii obsahuje podezrele malo bodu! ');
end

%Rozdeleni energii a prumerovani: 
if n==1 %Zprumerovani energii, kdyz byl meren jen jeden obrazek
 M=mean(EL.^mocnina);
 S=std(EL.^mocnina);
 M=M^(1/mocnina);
else
 if m<r %Prumerovani energii, kdyz EL obsahuje malo hodnot (nevynechaji se pauzy na vycitani kamery) 
  odd=0:m/n:m;
  odd=round(odd); %Poradi bodu jdoucich tesne pred zacatky prumerovanych useku 
  if length(odd)==n %Asi zbytecne, ale pro jistotu
   odd=[odd m];
  end
  for j=1:n, 
   pom=EL(odd(j)+1:odd(j+1)); %Vyber prumerovanych bodu 
   pom=pom.^mocnina;
   S(j)=std(pom);
   pom=mean(pom);
   pom=pom^(1/mocnina);
   M(j)=pom;
  end
 else %Pri prumerovani se vynechaji laserove pulzy, ktere pravdepodobne sly behem vycitani kamery. 
  d=(m-r)/(n-1); %Odhad poctu laserovych pulzu proslych behem vycitani kamery
  if d>2*tv*f
   disp('Pocet pulzu vynechanych na vycitani kamery je podezrele velky. ');
  end
  odd=0:(acc+d):m;
  odd=round(odd); %Poradi bodu jdoucich tesne pred zacatky prumerovanych useku 
  if length(odd)==n %Asi zbytecne, ale pro jistotu
   odd=[odd m];
  end
  for j=1:n, 
   if j<n
    pom=EL(odd(j)+1:odd(j+1)-round(d)); %Vyber prumerovanych bodu 
   elseif j==n
    pom=EL(odd(j)+1:odd(j+1)); %Vyber prumerovanych bodu posledniho useku (uz se nemuselo cekat na vycteni kamery)
   end
   pom=pom.^mocnina; 
   S(j)=std(pom); 
   pom=mean(pom);
   pom=pom^(1/mocnina);
   M(j)=pom;
  end
 end
end
